@@ -14,7 +14,9 @@ jomo1con<- function(Y, X=matrix(1,nrow(Y),1), betap=matrix(0,ncol(X),ncol(Y)), c
   colnamy<-colnames(Y)
   colnamx<-colnames(X)
   Y<-data.matrix(Y)
+  storage.mode(Y) <- "numeric"    
   X<-data.matrix(X)
+  storage.mode(X) <- "numeric"    
   if (output!=1) out.iter=nburn+nbetween
   imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+2)
   imp[1:nrow(Y),1:ncol(Y)]=Y
